@@ -1,4 +1,4 @@
-from gilda.process import depluralize
+from gilda.process import depluralize, replace_greek_spelled_out
 
 
 def test_depluralize():
@@ -8,4 +8,9 @@ def test_depluralize():
     assert depluralize('antibodies') == ('antibody', 'plural_ies')
     assert depluralize('branches') == ('branch', 'plural_es')
     assert depluralize('CDs') == ('CD', 'plural_caps_s')
-    assert depluralize('receptors') == ('receptor', 'plural_s')
\ No newline at end of file
+    assert depluralize('receptors') == ('receptor', 'plural_s')
+
+
+def test_greek():
+    assert replace_greek_spelled_out('interferon-γ') == \
+        'interferon-gamma'
